Displays a brief summary of the fitted model: family, dimensions, Rhat, divergences, chain return codes, priors, and total sampling time.
Usage
# S3 method for class 'bvarnet'
print(x, ...)Displays a brief summary of the fitted model: family, dimensions, Rhat, divergences, chain return codes, priors, and total sampling time.
# S3 method for class 'bvarnet'
print(x, ...)