Extracts posterior summaries from a fitted bvarnet object and
compares them to the true parameter values used for data generation.
Arguments
- fit
A fitted
bvarnetobject (output frombvar()).- truth
The
truthcomponent fromsim_var()output.- ci_width
Numeric. Width of the credible interval (default 0.90).
- bayes_factor
Logical; if
TRUE, compute Savage-Dickey BFs for beta and phi parameters and appendBF01,BF10, andbf_correctcolumns.bf_correctisTRUEwhen BF01 > 1 for true null parameters (true value ==null_value) and BF10 > 1 for true non-null parameters. DefaultFALSE.- null_value
Numeric scalar; the null hypothesis value for Bayes factor computation (default 0). Only used when
bayes_factor = TRUE.